@@ -2,7 +2,7 @@
 
 # ############################################################################ #
 #                                                                              #
-#   Copyleft (C) 2020-2021, Marek Gagolewski <https://www.gagolewski.com>      #
+#   Copyleft (C) 2020-2022, Marek Gagolewski <https://www.gagolewski.com>      #
 #                                                                              #
 #                                                                              #
 #   This program is free software: you can redistribute it and/or modify       #
@@ -23,7 +23,7 @@
 #' @title Minimum Spanning Tree of the Pairwise Distance Graph
 #'
 #' @description
-#' An parallelised implementation of a Jarník (Prim/Dijkstra)-like
+#' An parallelised implementation of a Jarnik (Prim/Dijkstra)-like
 #' algorithm for determining
 #' a(*) minimum spanning tree (MST) of a complete undirected graph
 #' representing a set of n points
@@ -66,19 +66,19 @@
 #'
 #'
 #' @references
-#' Jarník V., O jistém problému minimálním,
-#' Práce Moravské Přírodovědecké Společnosti 6 (1930) 57–63.
+#' V. Jarnik, O jistem problemu minimalnim,
+#' Prace Moravske Prirodovedecke Spolecnosti 6 (1930) 57-63.
 #'
 #' Olson C.F., Parallel algorithms for hierarchical clustering,
-#' Parallel Comput. 21 (1995) 1313–1325.
+#' Parallel Comput. 21 (1995) 1313-1325.
 #'
 #' Prim R., Shortest connection networks and some generalisations,
-#' Bell Syst. Tech. J. 36 (1957) 1389–1401.
+#' Bell Syst. Tech. J. 36 (1957) 1389-1401.
 #'
 #' Campello R., Moulavi D., Zimek A., Sander J.,
 #' Hierarchical density estimates for data clustering, visualization,
 #' and outlier detection,
-#' ACM Transactions on Knowledge Discovery from Data 10(1) (2015) 5:1–5:51.
+#' ACM Transactions on Knowledge Discovery from Data 10(1) (2015) 5:1-5:51.
 #'
 #'
 #' @param d either a numeric matrix (or an object coercible to one,
@@ -176,8 +176,9 @@ registerS3method("mst", "dist",    "mst.dist")
 #' @title Euclidean Minimum Spanning Tree
 #'
 #' @description
-#' Provides access to an implementation of the Dual-Tree Borůvka
-#' algorithm based on kd-trees from MLPACK. It is fast for (very) low-dimensional
+#' Provides access to the implementation of the Dual-Tree Boruvka
+#' algorithm from the \code{mlpack} package (if available).
+#' It is based on kd-trees and is fast for (very) low-dimensional
 #' Euclidean spaces. For higher dimensional spaces (say, over 5 features)
 #' or other metrics, use the parallelised Prim-like algorithm implemented
 #' in \code{\link{mst}()}.
@@ -185,6 +186,9 @@ registerS3method("mst", "dist",    "mst.dist")
 #'
 #' @param X a numeric matrix (or an object coercible to one,
 #'     e.g., a data frame with numeric-like columns)
+#' @param leaf_size size of leaves in the kd-tree,
+#'     controls the trade-off between speed and memory consumption
+#' @param naive logical; whether to use the naive, quadratic-time algorithm
 #' @param verbose logical; whether to print diagnostic messages
 #'
 #' @return
@@ -200,14 +204,21 @@ registerS3method("mst", "dist",    "mst.dist")
 #' Journal of Open Source Software 3(26), 726, 2018.
 #'
 #' @export
-emst_mlpack <- function(X, verbose=FALSE)
+emst_mlpack <- function(X, leaf_size=1, naive=FALSE, verbose=FALSE)
 {
     X <- as.matrix(X)
 
-    if (!verbose)
-        capture.output({mst <- .emst_mlpack(X)})
-    else
-        mst <- .emst_mlpack(X)
+    if (!requireNamespace("mlpack", quietly=TRUE)) {
+        warning("Package `mlpack` is not installed. Using mst() instead.")
+        return(mst.default(X, verbose=verbose, cast_float32=FALSE))
+    }
+
+    mst <- mlpack::emst(X, leaf_size=leaf_size, naive=naive, verbose=verbose)$output
+
+    mst[, 1] <- mst[, 1] + 1  # 0-based -> 1-based indexing
+    mst[, 2] <- mst[, 2] + 1  # 0-based -> 1-based indexing
+    stopifnot(mst[, 1] < mst[, 2])
+    stopifnot(!is.unsorted(mst[, 3]))
 
     structure(
         mst,
